Monty Python's Flying Circus: Just the Words - Episode 4

# Episode Four: Owl-stretching time

Song ('And did those feet')
Art gallery
Art critic
It's a man's life in the modern army
Undressing in public
Self-defence
Secret Service dentists

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| A cliff. Suddenly the 'It's' man is thrown over it, landing on the shale beach beneath. Painfully he crawls towards the camera and announces:
It's Man | It's...
Voice Over | (and CAPTION:) 'MONTY PYTHON'S FLYING CIRCUS'
| CAPTION: 'EPISODE ARTHUR' CAPTION: 'PART 7' CAPTION: 'TEETH'
| Singer in sprangly jacket sitting on high stool with guitar.
Singer | (singing to the tune of Jerusalem) And did those teeth in ancient time...
| CAPTION: 'LIVE FROM THE CARDIFF ROOMS, LIBYA'
Singer | ... walk upon England's mountains green. (he stops playing) Good evening and welcome ladies and gentlemen. At this time we'd like to up the tempo a little, change the mood. We've got a number requested by Pip, Pauline, Nigel, Tarquin, and old Spotty - Tarquin's mother - a little number specially written for the pubescence of ex-King Zog of Albania, and it's entitled 'Art Gallery'. Hope you like it.
| Interior of art gallery. Two figures enter. They are both middle-aged working mothers. Each holds the hand of an unseen infant who is beneath the range of the camera.
Janet | 'Allo, Marge!
Marge | Oh hello, Janet, how are you love?
Janet | Fancy seeing you! How's little Ralph?
Marge | Oh, don't ask me! He's been nothing but trouble all morning. Stop it Ralph! (she slaps at unseen infant) Stop it!
Janet | Same as my Kevin.
Marge | Really?
Janet | Nothing but trouble ... leave it alone! He's just been in the Florentine Room and smeared tomato ketchup all over Raphael's Baby Jesus. (shouting off sharply) Put that Baroque masterpiece down!
Marge | Well, we've just come from the Courtauld and Ralph smashed every exhibit but one in the Danish Contemporary Sculpture Exhibition.
Janet | Just like my Kevin. Show him an exhibition of early eighteenth-century Dresden Pottery and he goes berserk. No, I said no, and I meant no! (smacks unseen infant again) This morning we were viewing the early Flemish Masters of the Renaissance and Mannerist Schools, when he gets out his black aerosol and squirts Vermeer's Lady At A Window!
Marge | Still it's not as bad as spitting is it?
Janet | (firmly) No, well Kevin knows (slaps the infant) that if he spits at a painting I'll never take him to an exhibition again.
Marge | Ralph used to spit - he could hit a Van Gogh at thirty yards. But he knows now it's wrong - don't you Ralph? (she looks down) Ralph! Stop it! Stop it! Stop chewing that Turner! You are ... (she disappears from shot) You are a naughty, naughty, vicious little boy. (smack; she comes back into shot holding a copy of Turner's Fighting Temeraire in a lovely gilt frame but all tattered) Oh, look at that! The Fighting Temeraire - ruined! What shall I do?
Janet | (taking control) Now don't do a thing with it love, just put it in the bin over there.
Marge | Really?
Janet | Yes take my word for it, Marge. Kevin's eaten most of the early nineteenth-century British landscape artists, and I've learned not to worry. As a matter of fact, I feel a bit peckish myself. (she breaks a bit off the Turner) Yes...
| Marge also tastes a bit.
Marge | I never used to like Turner.
Janet | (swallowing) No ... I don't know much about art, but I know what I like.
| Cut to a book-lined study. At a desk in front of the shelves sits an art critic with a mouthful of Utrillo. SUPERIMPOSED CAPTION: 'AN ART CRITIC'
Critic | (taking out stringy bits as he speaks) Mmmm... (munches) Well I think Utrillo's brushwork is fantastic... (stifles burp) But he doesn't always agree with me ... (belches) Not after a Rubens, anyway ... all those cherries ... ooohh ... (suddenly looks down) Urgh! I've got Vermeer all down my shirt...
Wife (Katya Wyeth) | (bringing in a water jug and glass on a tray and laying it on his desk) Watteau, dear?
Critic | What a terrible joke.
Wife | But it's my only line.
Critic | (rising vehemently) All right! All right! But you didn't have to say it! You could have kept quiet for a change!
| Wife cries.
Critic | Oh, that's typical. Talk talk talk. Natter natter natter!
| Cut back to singer.
Singer | (singing) Bring me my arrows of desire ... Bring me my spear oh clouds unfold ... Bring me my chariot of fire.
| A sexy girl (Katya Wyeth) enters and starts fondling him.
| CAPTION: 'IT'S A MAN'S LIFE IN THE CARDIFF ROOMS, LIBYA'. Cut to colonel: army recruitment posters on wall behind him.
Colonel | Right, cut to me. As Officer Commanding the Regular Army's Advertising Division, I object, in the strongest possible terms to this obvious reference to our own slogan 'It's a dog's life... (correcting himself rapidly) a man's life in the modern army' and I warn this programme that any recurrence of this sloppy long-haired civilian plagiarism will be dealt with most severely. Right, now on the command 'cut', the camera will cut to camera two, all right, director... (cut to a man sitting at desk) Wait for it! (cut back to colonel) Camera cut. (cut to man; he has a Viking helmet on)
Man | This is my only line. (catcalls) (defensively) Well, it's my only line.
| Cut to a gentleman in striped blazer, boater and cricket flannels walking down to beach clutching towel and bathing trunks. He puts his towel on a breakwater next to another towel and starts to change. He suddenly looks up and we see everyone on the beach has turned to watch him - not with any disapproval - just a blank English stare. He grabs his towel off the breakwater and starts to take his trousers off under that. Girl in a bikini has been sitting on other side of the breakwater, stands up looking for her towel. She sees that the man is using it and she whisks it off him leaving him clutching his half-down trousers. Shot of everyone staring at him again. He pulls them up and makes for a beach hut... embarrassed. He goes into beach hut. Inside he is about to take his trousers off, when he becomes aware of a pair of feet which come up to the back of the beach hut - there is a 6-inch gap along bottom - and stop as if someone was peering through the crack. The man looks slightly outraged and pulls his trousers up, goes outside and edges cautiously round to the back of the beach hut. There he finds a man (Michael) bending close to the side of the beach hut with his hand to his face. The Gentleman kicks him hard in the seat of the pants. The man turns in obvious surprise, to reveal he was merely trying to light his cigarette out of the wind. The gentleman backs away with embarrassed apologies. We cut to the front of the beach hut to see gentleman backing round at the same time as a large matronly woman marches into the hut... the man follows her in. He is promptly thrown out on his ear. In desperation he looks around. On the promenade he suddenly sees an ice-cream van. He walks up to it, looks around, then nips behind to start changing. At the same time a policeman (Graham) strolls up to the ice-cream van and tells it to move on. The van drives off, exposing the gentleman clutching his trousers around his ankles. Close-up policeman's reaction. The man hurriedly pulls trousers up as policeman approaches him pulling out note book. Still covered in confusion he runs away from the policeman. In long shot we see him approach the commissionaire of the Royale Palace De Luxe Hotel. He whispers to the commissionaire, indicates by mime that he wants to take his trousers off. The commissionaire reacts to the gesture. The man nods. The commissionaire starts to take his trousers off. Man backs away once more in confusion - he has been misunderstood. Back on the beach again. He hides behind a pile of deckchairs. At that moment a beach party of jolly trippers arrive and each takes one. The deckchair pile rapidly disappears leaving the gentleman once again exposed. He dashes behind the deckchair attendant's hut which is next to him. Enter two workmen who dismantle it. Desperate by now he goes onto the pier. He goes into the amusement arcade, looking around furtively. Nips behind a 'what the butler saw' machine. Woman comes and puts penny in and starts to look, beckons over husband; he comes, looks in the machine, sees the man changing his trousers. They chase him off. Still pursued he nips into door. Finds himself in blackness. Relieved - at last he has found somewhere to change. He relaxes and starts to take his trousers off. Suddenly hears music and applause... curtains swishes back to reveal he is on stage of the pier pavilion. The audience applauds. Resigned to his fate, he breaks into stiptease routine.
Voice Over | (and CAPTION:) 'IT'S A MAN'S LIFE TAKING YOUR CLOTHES OFF IN PUBLIC'
| Cut to colonel
Colonel | Quiet. Quiet. Now wait a minute. I have already warned this programme about infringing the Army copyright of our slogan 'It's a pig's life... man's life in the modern army'. And I'm warning you if it happens again, I shall come down on this programme like a ton of bricks... right. Carry on sergeant major.
| A gym. Four men waiting there, with an ex-RSM type.
RSM | Sir! Good evening, class.
All | Good evening.
RSM | Where's all the others, then?
All | They're not here.
RSM | I can see that. What's the matter with them?
All | Don't know.
First Man | Perhaps they've got flu.
RSM | Flu...flu? They should eat more fresh fruit. (does terrible twitch or tic) Right. Now, self-defence. Tonight I shall be carrying on from where we got to last week when I was showing you how to defend yourselves against anyone who attacks you with armed with a piece of fresh fruit.
All | (disappointed) Oh.
Second Man | You promised you wouldn't do fruit this week.
RSM | What do you mean?
Third Man | We've done fruit the last nine weeks.
RSM | What's wrong with fruit? You think you know it all, eh?
Second Man | But couldn't we do something else, for a change?
Fourth Man | Like someone who attacks you with a pointed stick?
RSM | (scornfully) Pointed sticks? Ho, ho, ho. We want to learn how to defend ourselves against pointed sticks, do we? Getting all high and mighty, eh? Fresh fruit not good enough for you eh? Well I'll tell you something my lad. When you're walking home tonight and some great homicidal maniac comes after you with a bunch of loganberries, don't come crying to me! Now, the passion fruit. When your assailant lunges at you with a passion fruit, thus... (demonstrates)
All | We've done the passion fruit.
RSM | What?
First Man | We've done the passion fruit.
Second Man | We done oranges, apples, grapefruits.
Third Man | Whole and segments.
Second Man | Pomegranates, greengages.
First Man | Grapes, passion fruit.
Second Man | Lemons.
Third Man | Plums.
First Man | Yes, and mangoes in syrup.
RSM | How about cherries?
All | We done them.
RSM | Red and black?
All | Yes.
RSM | All right then...bananas!
All | Oh.
RSM | We haven't done them, have we?
All | No.
RSM | Right! Bananas! How to defend yourself against a man armed with a banana. (to first man) Here, you, take this. (throws him a banana) Now, it's quite simple to defend yourself against the banana fiend. First of all, you force him to drop the banana, next, you eat the banana, thus disarming him. You have now rendered him helpless.
Second Man | Suppose he's got a bunch.
RSM | Shut up!
Fourth Man | Supposing he's got a pointed stick.
RSM | Shut up. Right now you, Mr Apricot.
First Man | Harrison.
RSM | Harrison, Mr. Harrison. Come at me with that banana then. Come on attack me with it. As hard as you like. Come on. (Harrison moves towards him rather half-heartedly) No no no. Put something into it for God's sake. Hold it, like that. Scream. Now come on, come on...attack me, come on, come on (Harrison runs towards him shouting; RSM draws a revolver and fires it, right in Harrison's face; Harrison dies immediately, falling to the ground; RSM puts gun away and walks to banana) Now...I eat the banana.
| He does so; the rest of the class gather around Mr Harrison's body
All | You shot him. He's dead...dead. He's completely dead. You've shot him.
RSM | (finishing the banana) I have now eaten the banana. The deceased Mr Apricot is now disarmed.
Second Man | You shot him. You shot him dead.
RSM | Well, he was attacking me with a banana.
Third Man | Well, you told him to.
RSM | Look, I'm only doing me job. I have to show you how to defend yourselves against fresh fruit.
Fourth Man | And pointed sticks.
RSM | Shut up.
Second Man | Supposing someone came at you with a banana and you haven't got a gun?
RSM | Run for it.
Third Man | You could stand and scream for help.
RSM | You try that with a pineapple down your windpipe.
Third Man | A pineapple?
RSM | (jumping with fear) Where? Where?
Third Man | Nowhere. I was just saying pineapple.
RSM | Oh blimey. I thought my number was on that one.
Third Man | (amazed) What, on the pineapple?
RSM | (jumping) Where? Where?
Third Man | No I was just repeating it.
RSM | Oh. Oh. Right. That's the banana then. Next... the raspberry. (pulling one out of pocket) Harmless looking thing, isn't it? Now you, Mr Tinned Peach...
Third Man | Thompson.
RSM | Mr Thompson, come at me with that raspberry then. Come on, be as vicious as you like with it.
Third Man | No.
RSM | Why not?
Third Man | You'll shoot me.
RSM | I won't.
Third Man | You shot Mr. Harrison.
RSM | That was self-defence. Come on. I promise I won't shoot you.
Fourth Man | You promised you'd tell us about pointed sticks.
RSM | Shut up. Now. Brandish that...brandish that raspberry. Come on, be as vicious as you like with it. Come on.
Third Man | No. Throw the gun away.
RSM | I haven't got a gun.
Third Man | Oh yes, you have.
RSM | I haven't.
Third Man | You have. You shot Mr Harrison with it.
RSM | Oh... that gun.
Third Man | Throw it away.
RSM | All right. (throws it away) How to defend yourself against a raspberry, without a gun.
Third Man | You were going to shoot me!
RSM | I wasn't.
Third Man | You were.
RSM | Wasn't. Come on, come on you worm...you miserable little man. Come at me then...come on, do your worst, you worm. (third man runs at him; the RSM steps back and pulls a lever; a sixteen-ton weight falls upon the man) If anyone ever attacks you with a raspberry, simply pull the lever...and a sixteen-ton weight will drop on his head. I learnt that in Malaya.
Second Man | Suppose you haven't got a sixteen-ton weight?
RSM | Well that's planning, isn't it? Forethought.
Second Man | How many sixteen-ton weights are there?
RSM | Look...look, smarty pants, the sixteen-ton weight is just one way of dealing with the raspberry killer. There are millions of others!
Fourth Man | Like what?
RSM | Shoot him.
Second Man | Well, supposing you haven't got a gun or a sixteen-ton weight?
RSM | All right clever dick, all right clever dick. You two, come at me with raspberries, there you are, a whole basket each. Come on, come at me with them, then.
Second Man | No gun?
RSM | No.
Second Man | No sixteen-ton weight?
RSM | No.
Fourth Man | No pointed stick?
RSM | Shut up.
Second Man | No rocks up in the ceiling?
RSM | No.
Second Man | You won't kill us.
RSM | I won't kill you.
Second Man | Promise.
RSM | I promise I won't kill you. Now, are you going to attack me?
Second Man and Fourth Man | All right.
RSM | Right, now don't rush me this time. I'm going to turn me back. So you can stalk me...right. Come up as quietly as you can, right, close up behind me, then, in with the raspberries, right? Start moving (they start to creep up behind him) Now...the first thing to do when you are being stalked by an ugly mob with raspberries, is to...release the tiger. (he presses button and a tiger flashes past him in direction of second and fourth men; cries are heard from them as well as roaring) The great advantage of the tiger in unarmed combat is that it not only eats the raspberry-laden foe but also the raspberries. The tiger, however, do not relish the peach. The peach assailant should be attacked with a crocodile. (he turns to lok at the scene) Right...I know you're there - lurking under the floorboards with your damsons and your prunes...now, the rest of you - I know you're hiding behind the wall bars with your quinces. Well I'm ready for you. I've wired myself up to two hundred tons of gelignite, and if any one of you so much as tries anything we'll all go up together! I've warned you...I warned you, right. That's it...
| Big explosion.
| ANIMATION: Ends with cut-out animation of sedan chair; matching shot links into next film. Cut to deserted beach. Sedan chair arrives at deserted beach. Flunkey opens the door. Gentleman gets out in his eighteenth-century finery. The flunkeys help him to change into a lace-trimmed striped bathing costume. He then gets back into the sedan chair and they all trot off onto the sea. Cut to singer in bed with woman. Singer reclining with guitar.
Singer | And did those feet in ancient times, walk upon England's mountains green...we'd like to alter the mood a little, we'd like to bring you something for mum and dad, Annie, and Roger, Mazarin and Louis and all at Versailles, it's a little number calld 'England's Mountains Green'. Hope you like it. And did those feet in ancient time...
| Cut to a man standing in the countryside.
Man | (rustic accent) Yes, you know it's a man's life in England's Mountain Green.
Colonel | Right I heard that, I heard that, I'm going to stop this sketch now, and if there's any more of this, I'm going to stop the whole programme. I thought it was supposed to be about teeth anyway. Why don't you do something about your teeth - go on. (walk off)
Man | What about my rustic monologue?...I'm not sleeping with that producer again.
| Cut to film of various sporting activities, wild west stage coach etc.
Voice Over | (with big music, excited) Excitement, drama, action, violence, fresh fruit. Passion. Thrills. Spills. Romance. Adventure, all the things you can read about in a book.
| Cut to bookshop. A bookseller is standing behind the counter. Arthur enters the shot and goes up to the counter. The bookseller jumps and look about furtively.
Bookseller | Er... oh!
Arthur | Good morning, I'd like to buy a book please.
Bookseller | Oh, well I'm afraid we don't have any. (trying to hide them)
Arthur | I'm sorry?
Bookseller | We don't have any books. We're fresh out of them. Good morning.
Arthur | Well what are all these?
Bookseller | All what? Oh! All these, ah ah ha ha. Your referring to these ... books.
Arthur | Yes.
Bookseller | They're um ... they're all sold. Good morning.
Arthur | What all of them?
Bookseller | Every single man Jack of them. Not a single one of them in an unsold state. Good morning.
Arthur | Who to?
Bookseller | What?
Arthur | Who are they sold to?
Bookseller | Oh ... various ... good Lord is that the time? Oh my goodness I must close for lunch.
Arthur | It's only half past ten.
Bookseller | Ah yes, well I feel rather peckish ... very peckish actually, I don't expect I'll open again today. I think I'll have a really good feed. I say! Look at that lovely bookshop just across the road there, they've got a much better selection than we've got, probably at ridiculously low prices ... just across the road there. (he has the door open) Good morning.
Arthur | But I was told to come here.
Bookseller | (bundling him back in) Well. Well, I see. Er ... (very, carefully) hear the gooseberries are doing well this year... and so are the mangoes. (winks)
Arthur | I'm sorry?
Bookseller | Er .,. oh . .. I was just saying ... thinking of the weather.. I hear the gooseberries are doing well this year... and so are the mangoes.
Arthur | Mine aren't
Bookseller | (nodding keenly, with anticipation) Go on...
Arthur | What?
Bookseller | Go on - mine aren't ... but...
Arthur | What?
Bookseller | Aren't you going to say something about 'mine aren't but the Big Cheese gets his at low tide tonight'?
Arthur | No.
Bookseller | Oh, ah, good morning, (starts to bundle him out then stops) Wait. Who sent you?
Arthur | The little old lady in the sweet shop.
Bookseller | She didn't have a duelling scar just here ... and a hook?
Arthur | No.
Bookseller | Of course not, I was thinking of somebody else. Good morning.
Arthur | Wait a minute, there's something going on here.
Bookseller | (spinning round.) What, where? You didn't see anything did you?
Arthur | No, but I think there's something going on here.
Bookseller | No no, well there's nothing going on here at all (shouts off) and he didn't see anything. Good morning.
Arthur | (coming back into shop) There is something going on.
Bookseller | Look there is nothing going on. Please believe me, there is abso... (a hand comes into view behind Arthur's back; Bookseller frantically waves at it to disappear; it does so) . . . lutely nothing going on. Is there anything going on?
| A man appears, fleetingly: he is Van der Berg (Dick Vosburgh)
Van der Berg | No there's nothing going on. (disappears)
Bookseller | See there's nothing going on.
Arthur | Who was that?
Bookseller | That was my aunt, look what was this book you wanted then? Quickly! Quickly!
Arthur | Oh, well, I'd like to buy a copy of an 'Illustrated History of False Teeth'.
Bookseller | My God you've got guts.
Arthur | What?
Bookseller | (pulling gun) Just how much do you know?
Arthur | What about?
Bookseller | Are you from the British Dental Association?
Arthur | No I'm a tobacconist.
Bookseller | Get away from that door.
Arthur | I'll just go over the other...
Bookseller | Stay where you are. You'll never leave this bookshop alive.
Arthur | Why not?
Bookseller | You know too much, my dental friend.
Arthur | I don't know anything.
Bookseller | Come clean. You're a dentist aren't you.
Arthur | No, I'm a tobacconist.
Bookseller | A tobacconist who just happens to be buying a book on ...teeth?
Arthur | Yes.
Bookseller | Ha ha ha ha...
| Lafarge enters room with gun. He is swarthy, French, dressed all in black and menacing.
Lafarge | Drop that gun, Stapleton.
Bookseller | Lafarge! (he drops the gun)
Arthur | There is something going on.
Bookseller | No there isn't.
Lafarge | OK Stapleton, this is it. Where's Mahoney hidden the fillings?
Bookseller | What fillings?
Lafarge | You know which fillings, Stapleton. Upper right two and four, lower right three and two lower left one. Come on. (he threatens with the gun) Remember what happened to Nigel.
Arthur | What happened to Nigel?
Bookseller | Orthodontic Jake gave him a gelignite mouth wash.
Arthur | I knew there was something going on.
Bookseller | Well there isn't.
Lafarge | Come on Stapleton. The fillings!
Bookseller | They're at 22 Wimpole Street.
Lafarge | Don't play games with me! (pokes bookseller in eye with the gun)
Bookseller | Oh, oh, 22a Wimpole Street.
Lafarge | That's better.
Bookseller | But you'll need an appointment.
Lafarge | OK (shouting out of shop) Brian! Make with the appointment baby. No gas.
| Van der Berg appears with machine gun and a nurse (Carol), he is basically dressed as a dentist. But with many rings, chains, wristlets, cravats, buckled shoes and an ear-ring.
Van der Berg | Not so fast Lafarge!
Lafarge | Van der Berg!
Van der Berg | Yes. Now drop the roscoe.
Arthur | There is something going on.
Bookseller | No there isn't.
Van der Berg | Get the guns.
| The nurse runs forward, picks up the gun and puts it on steel surgeon's tray, and covers it with a white cloth, returning it to Van der Berg.
Arthur | Who's that?
Bookseller | That's Van der Berg. He's on our side.
Van der Berg | All right, get up against the wall Lafarge, and you too Stapleton.
Bookseller | Me?
Van der Berg | Yes, you!
Bookseller | You dirty double-crossing rat.
Arthur | (going with Bookseller) What's happened?
Bookseller | He's two-timed me.
Arthur | Bad luck.
Van der Berg | All right ... where are the fillings? Answer me, where are they?
Arthur | This is quite exciting.
| Brian enters carrying a bazooka. Brian is dressed in operating-theatre clothes, gown, cap and mask, with rubber gloves and white wellingtons.
Brian | Not so fast.
All | Brian!
Arthur | Ooh, what's that?
The Others | It's a bazooka.
Brian | All right. Get against the wall Van der Berg ... and you nurse. And the first one to try anything moves to a practice six feet underground ... this is an anti-tank gun ... and it's loaded ...and you've just got five seconds to tell me ... whatever happened to Baby Jane?
All | What?
Brian | Oh ... I'm sorry ... my mind was wandering ... I've had a terrible day... I really have ... you've got five seconds to tell me... I've forgotten. I've forgotten.
Bookseller | The five seconds haven't started yet have they?
Van der Berg | Only we don't know the question.
Arthur | Was it about Vogler?
Brian | No, no... no ... you've got five seconds to tell me...
Van der Berg | About Nigel?
Brian | No.
Lafarge | Bronski?
Brian | No. No.
Arthur | The fillings!
Brian | Oh yes, the fillings, of course. How stupid of me. Right, you've got five seconds ... (clears throat) Where are the fillings? Five, four, three, two, one, Zero! (there is a long pause, Brian has forgotten to fire the bazooka but he can't put his finger on what has gone wrong) Zero! (looks at gun) Oh! I've forgotten to fire it. Sorry. Silly day. Very well. (quite rapidly) Five, four, three, two, one.
| A panel slides back and the Big Cheese appears in sight seated in adentist's chair. The Big Cheese is in dentist's gear, wears evil magnifing type glasses and strokes a rabbit lying on his lap.
Big Cheese | Drop the bazooka Brian.
All | The Big Cheese!
| Brian drops the bazooka.
Big Cheese | I'm glad you could all come to my little ... party. And Flopsy's glad too, aren't you, Flopsy? (he holds rabbit up as it does not reply) Aren't you Flopsy? (no reply again so he pulls a big revolver out and fires at rabbit from point-blank range) That'll teach you to play hard to get. There, poor Flopsy's dead. And never called me mother. And soon ... you will all be dead, dead, dead, dead. (the crowd start to hiss him) And because I'm so evil you'll all die the slow way ... under the drill.
Arthur | lt's one o'clock.
Big Cheese | So it is. Lunch break, everyone back here at two.
| They, all happily relax and walk off. Arthur surreptitiously goes to telephone and, making sure nobody is looking, calls.
Arthur | Hallo ... give me the British Dental Association ... and fast.
| Cut to Arthur dressed normally as dentist leaning over patient in chair. He looks up to camera.
Arthur | You see, I knew there was something going on. Of course, the Big Cheese made two mistakes. First of all he didn't recognize me: Lemming, Arthur Lemming, Special Investigator, British Dental Association, and second ... (to patient) spit ... by the time I got back from lunch I had every dental surgeon in SW1 waiting for them all in the broom cupboard. Funny isn't it, how naughty dentists always make that one fatal mistake. Bye for now ... keep your teeth clean.
| Cut to photo of Arthur Lemming SUPERIMPOSED CAPTION: 'LEMMING OF THE BDA' Over this we hear a song which Graham knows the tune of.
Song | (Voice over pre-recorded) Lemming, Lemming ... Lemming of the BDA .. Lemming, Lemming ... Lemming of the BD ...Lemming of the BD ... BD, BDA.
Voice Over | (and CAPTION:) 'IT'S A MAN'S LIFE IN THE BRITISH DENTAL ASSOCIATION'
Colonel | (knocking the photo aside) Right! No, I warned you, no, I warned you about the slogan, right. That's the end. Stop the programme! Stop it.
| Cut to referee blowing whistle. The 'It's' man, lying on beach. is poked with a stick from off-screen. He gets up and limps away. CAPTION: '"OWL-STRETCHING TIME" WAS CONCIEVED, WRITTEN AND PERFORMED BY...(CREDITS)' End titles finishes as the 'It's' man reaches the top of the cliff and disappears. As soon as he has disappeared we hear:
Voice Over | Ah! Got you my lad. Still acting eh? Over you go!
| 'It's' man reappears hurled back over cliff.